@@ -5,6 +5,9 @@ set.seed(290875)
 library(coin)
 isequal <- coin:::isequal
 
+### check if doxygen documentation is there
+stopifnot(nchar(system.file("documentation/html/index.html", package = "coin")) > 29) 
+
 ### I() returns objects of class AsIs which caused an error in `trafo'
 df <- data.frame(x1 = rnorm(100), x2 = rnorm(100), x3 = gl(2, 50))
 independence_test(I(x1 / x2) ~ x3, data = df)
@@ -121,4 +124,4 @@ mydf <- data.frame(x = rnorm(10), y = rnorm(10), z = gl(2, 5))
 it <- independence_test(x + y ~ z, data = mydf)
 statistic(it, "linear")
 expectation(it)
-covariance(it)
\ No newline at end of file
+covariance(it)
